Module reader

Module reader 

View of jeff data.

Programs are composed of a top-level Module that contains a list of Functions.

Re-exports

pub use value::FunctionIOValue;
pub use value::ValueId;
pub use value::ValueTable;
pub use value::WireValue;

Modules

optype
Node operation definitions.
value
“Values” represent wire types in the jeff language with associated metadata.

Structs

FunctionDeclaration
Function declaration in a jeff module.
FunctionDefinition
Function definition in a jeff module.
Metadata
A metadata entry, consisting of a name and a value.
Module
Top-level module definition in a jeff program.
Operation
Operation in a dataflow graph.
Region
Dataflow region defined in a jeff module.

Enums

Function
Function in a jeff module.
ReadError
Errors that can occur when accessing a jeff program.

Traits

HasMetadata
Trait for types that have metadata entries.
ReadJeff
Structure that can return a read-only view of a jeff file.

Type Aliases

FunctionId
Function index into the module’s function table.