ControlFlowOp

Enum ControlFlowOp 

pub enum ControlFlowOp<'a> {
    Switch(SwitchOp<'a>),
    For {
        region: Region<'a>,
    },
    While {
        before: Region<'a>,
        after: Region<'a>,
    },
}
A structured control-flow operation.

Variants



Switch(SwitchOp<'a>)

Switch statement.

The first input to the switch is an integer that selects the branch by index. The operation has a region for every branch, together with an optional default region. If there is no default region, it is an error if the index does not match any branch.



For

For loop.

The loop iterates from start to stop (exclusive) by step. The region is the loop body that is executed once for each iteration. The loop maintains a state consisting of any number of values. Each iteration receives the state from the previous iteration, or the initial state for the first iteration. When the loop finishes, the final state is returned. Iterations also have access to the current iteration value.

Fields

region: Region<'a>

Internal DFG of the loop.



While

While loop.

The before region is executed at least once. If the condition is true, the after region is executed. The loop maintains a state consisting of any number of values. The before region receives the state from the after region, or the initial state for the first iteration. The after region receives the state from the before region. When the loop finishes, the final state is returned by the before region.

Fields

before: Region<'a>

The region that evaluates whether the condition is met.

after: Region<'a>

The body that is executed on each iteration.