#[non_exhaustive]pub enum FloatArrayOp<'a> {
Const32(ConstArray<'a, f32>),
Const64(ConstArray<'a, f64>),
Zero {
precision: FloatPrecision,
},
GetIndex,
SetIndex,
Length,
Create,
}Expand description
An operation over floating point arrays.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Const32(ConstArray<'a, f32>)
Create a constant 32 bit float array.
Const64(ConstArray<'a, f64>)
Create a constant 64 bit float array.
Zero
Create a zeroed float array of a given precision with dynamic length.
Fields

precision: FloatPrecisionThe precision of the floats in the array.
GetIndex
Get the value of a float array at a given index.
SetIndex
Set the value of a float array at a given index.
Length
Get the length of a float array.
Create
Creates a float array from a variable number of input values.