#[non_exhaustive]pub enum IntArrayOp<'a> {
ConstArray1(ConstArray<'a, bool>),
ConstArray8(ConstArray<'a, u8>),
ConstArray16(ConstArray<'a, u16>),
ConstArray32(ConstArray<'a, u32>),
ConstArray64(ConstArray<'a, u64>),
Zero {
bits: u8,
},
GetIndex,
SetIndex,
Length,
Create,
}Expand description
An operation over integer arrays.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ConstArray1(ConstArray<'a, bool>)
Create a constant 1 bit integer array.
ConstArray8(ConstArray<'a, u8>)
Create a constant 8 bit integer array.
ConstArray16(ConstArray<'a, u16>)
Create a constant 16 bit integer array.
ConstArray32(ConstArray<'a, u32>)
Create a constant 32 bit integer array.
ConstArray64(ConstArray<'a, u64>)
Create a constant 64 bit integer array.
Zero
Create a zeroed integer array of a given bitwidth with dynamic length.
GetIndex
Get the value of an integer array at a given index.
SetIndex
Set the value of an integer array at a given index.
Length
Get the length of an integer array.
Create
Creates an integer array from a variable number of input values.