IntOp

Enum IntOp 

#[non_exhaustive]
pub enum IntOp {
Show 29 variants Const1(bool), Const8(u8), Const16(u16), Const32(u32), Const64(u64), Add, Sub, Mul, DivS, DivU, Pow, And, Or, Xor, Not, MinS, MinU, MaxS, MaxU, Eq, LtS, LteS, LtU, LteU, Abs, RemS, RemU, Shl, Shr,
}
An operation over integers.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Const1(bool)

Create a constant 1 bit integer.



Const8(u8)

Create a constant 8 bit integer.



Const16(u16)

Create a constant 16 bit integer.



Const32(u32)

Create a constant 32 bit integer.



Const64(u64)

Create a constant 64 bit integer.



Add

Add two integers.



Sub

Subtract two integers.



Mul

Multiply two integers.



DivS

Divide two signed integers.



DivU

Divide two unsigned integers.



Pow

Take the power of an integer.



And

Logical bitwise AND.



Or

Logical bitwise OR.



Xor

Logical bitwise XOR.



Not

Logical bitwise NOT.



MinS

Minimum of two signed integers.



MinU

Minimum of two unsigned integers.



MaxS

Maximum of two signed integers.



MaxU

Maximum of two unsigned integers.



Eq

Test two integers for equality.



LtS

Check if one signed integer is strictly less than another.



LteS

Check if one signed integer is less than or equal to another.



LtU

Check if one unsigned integer is strictly less than another.



LteU

Check if one unsigned integer is less than or equal to another.



Abs

Take the absolute value of a signed integer.



RemS

Remainder of a division of two signed integers.



RemU

Remainder of a division of two unsigned integers.



Shl

Logical shift left.



Shr

Logical shift right.