WellKnownGate

Enum WellKnownGate 

#[non_exhaustive]
pub enum WellKnownGate {
Show 14 variants GPhase, I, X, Y, Z, S, T, R1, Rx, Ry, Rz, H, U, Swap,
}
Well-known quantum gates.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


GPhase

Global phase operation on the “vacuum” state (no qubits).

G = | exp(iθ) |

Inputs:

  • Float rotation in radians.

Outputs:

  • No outputs


I

Identity (no-op) gate on a single qubit.

I = | 1  0 |
    | 0  1 |

Inputs:

Outputs:



X

Pauli-X gate. Also known as the NOT gate.

X = | 0  1 |
    | 1  0 |

Inputs:

Outputs:



Y

Pauli-Y gate.

Y = | 0  -i |
    | i   0 |

Inputs:

Outputs:



Z

Pauli-Z gate.

Z = | 1   0 |
    | 0  -1 |

Inputs:

Outputs:



S

S gate.

S = | 1   0 |
    | 0   i |

Inputs:

Outputs:



T

T gate.

T = | 1   0        |
    | 0   exp(iπ/4)|

Inputs:

Outputs:



R1

Rotation around the |1> state.

R1(θ) = | 1   0       |
        | 0   exp(iθ) |

Inputs:

Outputs:



Rx

Rotation around the X axis.

Rx(θ) = |  cos(θ/2)  -isin(θ/2) |
        | -isin(θ/2)  cos(θ/2)  |

Inputs:

Outputs:



Ry

Rotation around the Y axis.

Ry(θ) = |  cos(θ/2)  -sin(θ/2) |
        |  sin(θ/2)   cos(θ/2) |

Inputs:

Outputs:



Rz

Rotation around the Z axis.

Rz(θ) = | exp(-iθ/2)   0         |
        | 0            exp(iθ/2) |

Inputs:

Outputs:



H

Hadamard gate.

H = 1/√2 | 1   1 |
         | 1  -1 |

Inputs:

Outputs:



U

Euler gate.

U(θ,φ,λ) = | cos(θ/2)          -exp(iλ)sin(θ/2)    |
          | exp(iφ)sin(θ/2)   exp(iλ)cos(θ/2)       |

Inputs:

Outputs:



Swap

Swap gate. Swaps the state of two qubits.

Swap = | 1   0   0   0 |
       | 0   0   1   0 |
       | 0   1   0   0 |
       | 0   0   0   1 |

Inputs:

Outputs:

Implementations

Source

impl WellKnownGate

pub fn num_qubits(&self) -> usize

Returns the number of qubits that the gate acts on.

pub fn num_params(&self) -> usize

Returns the number of floating point parameters that the gate takes as inputs.

pub fn from_name(name: &str) -> Option<Self>

Returns the well known gate corresponding to the given name.