GateOp

Struct GateOp 

#[non_exhaustive]
pub struct GateOp<'a> { pub gate_type: GateOpType<'a>, pub control_qubits: u8, pub adjoint: bool, pub power: u8, }
Quantum gate operation.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
gate_type: GateOpType<'a>

The type of gate.

control_qubits: u8

The number of control qubits for gate.

adjoint: bool

Whether to apply the adjoint of the named gate.

power: u8

A number of times to apply this gate in sequence.

Implementations

Source

impl GateOp<'_>

pub fn normalize(self) -> Self

If this gate has a custom identifier, try to convert it to a well-known gate and return the new gate operation.

Source

impl<'a> GateOp<'a>

pub fn num_qubits(&self) -> usize

Returns the number of qubits that the gate acts on.

pub fn num_params(&self) -> usize

Returns the number of floating point parameters that the gate takes as inputs.