pub struct SwitchOp<'a> { /* private fields */ }Expand description
A switch statement.
Implementations
Sourceimpl<'a> SwitchOp<'a>
impl<'a> SwitchOp<'a>
Sourcepub fn branches(&self) -> impl Iterator<Item = Region<'a>>
pub fn branches(&self) -> impl Iterator<Item = Region<'a>>
Returns an iterator over the branches of this switch statement.
Sourcepub fn branch_count(&self) -> usize
pub fn branch_count(&self) -> usize
Returns the number of branches in this switch statement.
Sourcepub fn branch(&self, n: usize) -> Region<'a>
pub fn branch(&self, n: usize) -> Region<'a>
Returns the n-th branch of this switch statement.
Panics
Panics if n is equal or greater than SwitchOp::branch_count.
Sourcepub fn try_branch(&self, n: usize) -> Option<Region<'a>>
pub fn try_branch(&self, n: usize) -> Option<Region<'a>>
Returns the n-th branch of this switch statement.
Returns None if n is equal or greater than SwitchOp::branch_count.
Sourcepub fn default_branch(&self) -> Option<Region<'_>>
pub fn default_branch(&self) -> Option<Region<'_>>
Returns the default branch of this switch statement.
Returns None if there is no default branch.