Region

Struct Region 

pub struct Region<'a> { /* private fields */ }
Dataflow region defined in a jeff module.

Implementations

Source

impl<'a> Region<'a>

pub fn boundary( &self, direction: Direction, ) -> impl Iterator<Item = Result<WireValue<'a>, ReadError>>

Returns an iterator over the sources or target values of this region.

Errors
pub fn sources(&self) -> impl Iterator<Item = Result<WireValue<'a>, ReadError>>

Return an iterator over the source values of this region.

Errors
pub fn targets(&self) -> impl Iterator<Item = Result<WireValue<'a>, ReadError>>

Return an iterator over the target values of this region.

Errors
pub fn boundary_count(&self, direction: Direction) -> usize

Returns the number of sources or target values in this region.

pub fn source_count(&self) -> usize

Returns the number of source values in this region.

pub fn target_count(&self) -> usize

Returns the number of target values in this region.

pub fn boundary_value( &self, direction: Direction, idx: usize, ) -> Option<Result<WireValue<'a>, ReadError>>

Returns the boundary value at the given index, or None if the index is out of bounds.

Errors
pub fn source(&self, idx: usize) -> Option<Result<WireValue<'a>, ReadError>>

Returns the source value at the given index, or None if the index is out of bounds.

Errors
pub fn target(&self, idx: usize) -> Option<Result<WireValue<'a>, ReadError>>

Returns the target value at the given index, or None if the index is out of bounds.

Errors
pub fn operations(&self) -> impl Iterator<Item = Operation<'a>>

Returns an iterator over the operations in this region.

pub fn operation_count(&self) -> usize

Returns the number of operations in this region.

pub fn operation(&self, n: usize) -> Operation<'a>

Returns the n-th operation in this region.

Panics

Panics if n is equal or greater than Region::operation_count.