Module value

Module value 

“Values” represent wire types in the jeff language with associated metadata.

There are two types of values:

  • WireValues that correspond to typed hyperedges in dataflow regions.
  • FunctionIOValues, describing the inputs and outputs of a function.

All regions inside a function share a single ValueTable listing all the hyperedges in the function. These are indexed by their ValueIds.

Structs

FunctionIOValue
Input/output type for a function, with associated metadata.
ValueTable
Table of values / typed hyperedges contained in a function.
WireValue
Wire type and associated metadata.

Type Aliases

ValueId
The ID of a value hyperedge in the function’s value table.