Type

Enum Type 

pub enum Type {
    Qubit,
    QubitRegister {
        length: Option<u32>,
    },
    Int {
        bits: u8,
    },
    IntArray {
        bits: u8,
        length: Option<u32>,
    },
    Float {
        precision: FloatPrecision,
    },
    FloatArray {
        precision: FloatPrecision,
        length: Option<u32>,
    },
}
Value type.

Variants



Qubit

Quantum bit.

Qubits are linear types.



QubitRegister

Quantum registers.

A quantum register is an array of slots that can hold qubits. Slots of a quantum register can either be empty or filled with a qubit.

Quantum registers are linear types.

If length is None, the register has dynamic length. If Some, the register has static compile-time length.

Fields

length: Option<u32>

Optional compile-time length.



Int

Integers.

The type does not distinguish between signed and unsigned integers. Instead it is up to the operation to interpret the integer as signed or unsigned. Signed integers are represented using two’s complement.

Integers of bitwidth 1 can be used as classical bits or boolean values.

Fields

bits: u8

Bitwidth of the integer.



IntArray

Integer array.

Arrays of integers of bitwidth 1 can be used as classical bit arrays.

If length is None, the array has dynamic length. If Some, the array has static compile-time length.

Fields

bits: u8

Bitwidth of the integers.

length: Option<u32>

Optional compile-time length.



Float

Floating point numbers.

Fields

precision: FloatPrecision

Precision of the floating point number.



FloatArray

Array of floating point numbers.

If length is None, the array has dynamic length. If Some, the array has static compile-time length.

Fields

precision: FloatPrecision

Precision of the floating point numbers.

length: Option<u32>

Optional compile-time length.

Implementations

Source

impl Type

pub fn int(bits: u8) -> Self

Create a new integer type.

pub fn bool() -> Self

Create a new boolean type.

pub fn int_array(bits: u8, length: Option<u32>) -> Self

Create a new integer array type.

If length is None, the array has dynamic length. If Some, the array has static compile-time length.

pub fn float(precision: FloatPrecision) -> Self

Create a new floating point type.

pub fn float_array(precision: FloatPrecision, length: Option<u32>) -> Self

Create a new floating point array type.

If length is None, the array has dynamic length. If Some, the array has static compile-time length.