Re-exports
pub use value::FunctionIOValue;pub use value::ValueId;pub use value::ValueTable;pub use value::WireValue;
Modules
- optype
- Node operation definitions.
- value
- “Values” represent wire types in the jeff language with associated metadata.
Structs
- Function
Declaration - Function declaration in a jeff module.
- Function
Definition - Function definition in a jeff module.
- Metadata
- A metadata entry, consisting of a name and a value.
- Module
- Top-level module definition in a jeff program.
- Operation
- Operation in a dataflow graph.
- Region
- Dataflow region defined in a jeff module.
Enums
Traits
- HasMetadata
- Trait for types that have metadata entries.
- Read
Jeff - Structure that can return a read-only view of a jeff file.
Type Aliases
- Function
Id - Function index into the module’s function table.