#[non_exhaustive]pub enum FloatOp {
}Expand description
An operation over floating point numbers.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Const32(f32)
Create a constant 32 bit float.
Const64(f64)
Create a constant 64 bit float.
Add
Add two floats.
Sub
Subtract two floats.
Mul
Multiply two floats.
Pow
Calculate one float raised to the power of another.
Eq
Test two floats for equality.
Lt
Check if one float is strictly less than another.
Lte
Check if one float is less than or equal to another.
Sqrt
Calculate the square root of a float.
Abs
Calculate the absolute value of a float.
Ceil
Round a float up to the nearest integer.
Floor
Round a float down to the nearest integer.
IsNan
Check if a float is NaN.
IsInf
Check if a float is infinite.
Exp
Calculate e raised to the power of a float.
Log
Calculate the natural logarithm of a float.
Sin
Calculate the sine of a float.
Cos
Calculate the cosine of a float.
Tan
Calculate the tangent of a float.
Asin
Calculate the arcsine of a float.
Acos
Calculate the arccosine of a float.
Atan
Calculate the arctangent of a float.
Atan2
Calculate the 2-argument arctangent.
Sinh
Calculate the hyperbolic sine of a float.
Cosh
Calculate the hyperbolic cosine of a float.
Tanh
Calculate the hyperbolic tangent of a float.
Asinh
Calculate the inverse hyperbolic sine of a float.
Acosh
Calculate the inverse hyperbolic cosine of a float.
Atanh
Calculate the inverse hyperbolic tangent of a float.
Max
Maximum of two floats.
Min
Minimum of two floats.