#[non_exhaustive]pub enum QubitOp<'a> {
Alloc,
Free,
FreeZero,
Measure,
MeasureNd,
Reset,
Gate(GateOp<'a>),
}Expand description
An operation over qubits.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Alloc
Allocates a new qubit in the |0> state.
Free
Frees a qubit.
This operation makes no assumptions about the state of the qubit.
FreeZero
Frees a qubit in the |0> state.
This operation can be used to avoid performing resets when it is known that the qubit has already been reset. It is undefined behavior to free a qubit that is not in the |0> state.
Measure
Perform a destructive measurement of a qubit in the computational basis.
MeasureNd
Perform a non-destructive measurement of a qubit in the computational basis.
Reset
Resets a qubit to the |0> state.
Gate(GateOp<'a>)
Apply a quantum gate.