#[non_exhaustive]pub enum QubitRegisterOp {
Alloc = 0,
Free = 10,
FreeZero = 1,
ExtractIndex = 2,
InsertIndex = 3,
ExtractSlice = 4,
InsertSlice = 5,
Length = 6,
Split = 7,
Join = 8,
Create = 9,
}Expand description
An operation over qubit registers.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Alloc = 0
Allocates a new qubit register given a number of qubits in the |0> state.
Free = 10
Frees a qubit register.
This operation makes no assumptions about the state of the qubits.
FreeZero = 1
Frees a qubit register, assuming that all qubits are in the |0> state.
It is undefined behavior to free a qubit register containing qubits that are not in the |0> state.
ExtractIndex = 2
Extracts a single qubit from a qubit register.
The slot must have been filled before and is marked as empty after the extraction.
InsertIndex = 3
Insert a single qubit into a qubit register.
The slot must have been empty before and is marked as filled after the insertion.
ExtractSlice = 4
Extract a slice of qubits from a qubit register given a range of indices.
All slots in the range are marked as empty in the original register.
InsertSlice = 5
Insert a slice of qubits into a qubit register.
All slots in the inserted range in the original register must have been empty.
Length = 6
Returns the length of the qubit register.
Split = 7
Splits a qubit register into two qubit registers at a given index.
Join = 8
Joins together two qubit registers into a single qubit register.
Create = 9
Creates a qubit register from a variable number of input qubits.