#[non_exhaustive]pub enum WellKnownGate {
Show 14 variants
GPhase,
I,
X,
Y,
Z,
S,
T,
R1,
Rx,
Ry,
Rz,
H,
U,
Swap,
}Expand description
Well-known quantum gates.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GPhase
Global phase operation on the “vacuum” state (no qubits).
G = | exp(iθ) |Inputs:
Floatrotation in radians.
Outputs:
- No outputs
I
Identity (no-op) gate on a single qubit.
I = | 1 0 |
| 0 1 |Inputs:
Qubitto act on.
Outputs:
Qubitacted on.
X
Pauli-X gate. Also known as the NOT gate.
X = | 0 1 |
| 1 0 |Inputs:
Qubitto act on.
Outputs:
Qubitacted on.
Y
Z
S
T
R1
Rx
Rotation around the X axis.
Rx(θ) = | cos(θ/2) -isin(θ/2) |
| -isin(θ/2) cos(θ/2) |Inputs:
Outputs:
Qubitacted on.
Ry
Rotation around the Y axis.
Ry(θ) = | cos(θ/2) -sin(θ/2) |
| sin(θ/2) cos(θ/2) |Inputs:
Outputs:
Qubitacted on.
Rz
Rotation around the Z axis.
Rz(θ) = | exp(-iθ/2) 0 |
| 0 exp(iθ/2) |Inputs:
Outputs:
Qubitacted on.
H
U
Euler gate.
U(θ,φ,λ) = | cos(θ/2) -exp(iλ)sin(θ/2) |
| exp(iφ)sin(θ/2) exp(iλ)cos(θ/2) |Inputs:
Outputs:
Qubitacted on.
Swap
Implementations
Sourceimpl WellKnownGate
impl WellKnownGate
Sourcepub fn num_qubits(&self) -> usize
pub fn num_qubits(&self) -> usize
Returns the number of qubits that the gate acts on.
Sourcepub fn num_params(&self) -> usize
pub fn num_params(&self) -> usize
Returns the number of floating point parameters that the gate takes as inputs.